#!/usr/bin/env bash
#
# Usage: create_resource.sh resource_group_name cluster_name namespace cluster_location subscription_id tenant_id client_id identity_name
#

readonly RES_GROUP_NAME=$1
readonly CLUSTER_NAME=$2
readonly NAMESPACE=$3
readonly CLUSTER_LOCATION=$4
readonly SUBSCRIPTION_ID=$5
readonly TENANT_ID=$6
readonly CLIENT_ID=$7
readonly IDENTITY_NAME=$8
readonly service_account_prefix=$9

: \
  ${LUNA_MANAGER_REPO:="elotl/luna-trial"} \
  ${LUNA_WEBHOOK_REPO:="elotl/luna-admission-webhook-trial"}

function create_namespace_if_not_exist() {
  kubectl create namespace "$NAMESPACE" --dry-run=client -o yaml | kubectl apply -f -
}

function create_docker_secret_if_not_exist() {
  kubectl create secret docker-registry -n "$NAMESPACE" "$DOCKER_SECRET_NAME" \
    --docker-server=docker.io \
    --docker-username="$DOCKER_USERNAME" \
    --docker-password="$DOCKER_PASSWORD" \
    --dry-run=client -o yaml | kubectl apply -f -
}

create_namespace_if_not_exist
create_docker_secret_if_not_exist

readonly helm_values="./${CLUSTER_NAME}_values.yaml"

cat <<EOF >"$helm_values"
cloudProvider: azure
clusterID: ${CLUSTER_NAME}
azure:
  clusterLocation: ${CLUSTER_LOCATION}
  resourceGroupName: ${RES_GROUP_NAME}
  subscriptionId: ${SUBSCRIPTION_ID}
  tenantId: ${TENANT_ID}
  clientId: ${CLIENT_ID}
  managedIdentity: ${IDENTITY_NAME}
  clientSecret: "${AZURE_CLIENT_SECRET}"
labels: "elotl-luna=true"
imageRepo: ${LUNA_MANAGER_REPO}
webhookRepo: ${LUNA_WEBHOOK_REPO}
serviceAccount:
  prefix: ${service_account_prefix}
EOF
