#!/usr/bin/env bash

readonly cluster_name=$1
readonly aws_region=$2

readonly RELEASE_NAME=${LUNA_RELEASE_NAME:-"elotl-luna"}
readonly CLUSTER_NAMESPACE=${LUNA_CLUSTER_NAMESPACE:-"elotl"}

if [ -z "$cluster_name" -o -z "$aws_region" ]
then
    echo "Usage: $0 <cluster-name> <aws-region>"
    exit 1
fi

_aws() {
    command aws --region="$aws_region" "$@"
}

remove_tags() {
    _aws ec2 describe-instances \
      --filter 'Name=instance-state-name,Values=running' \
      "Name=tag:kubernetes.io/cluster/${cluster_name},Values=owned" \
      --query 'Reservations[].Instances[].SecurityGroups[*].GroupId' \
      --output text |
    sed 's/\t/\n/g'| sort -u | while read -r sg_id
    do
        printf 'removing tag from %s\n' "$sg_id" > /dev/stderr
        _aws ec2 delete-tags \
          --resources "$sg_id" \
          --tags "Key=elotl.co/nodeless-cluster/name,Value=${cluster_name}" || die
    done
}

get_policy_arn_from_name() {
  _aws iam list-policies --query 'Policies[*].[PolicyName,Arn]' --output text |
    grep "$1" |
    awk '{ print $2 }'
}

readonly policy_name="$cluster_name-$CLUSTER_NAMESPACE-LunaAssumeRoleWithWebIdentity"
readonly role_name="$cluster_name-$CLUSTER_NAMESPACE-node_manager"
readonly policy_arn=$(get_policy_arn_from_name "$policy_name")

remove_iam_resources() {
  _aws iam detach-role-policy \
    --role-name "$role_name" \
    --policy-arn "$policy_arn" || true
  _aws iam delete-role --role-name "$role_name" || true
  _aws iam delete-policy --policy-arn "$policy_arn" || true
}

remove_dockerhub_secret() {
    kubectl delete secret -n "$CLUSTER_NAMESPACE" dockerhub
}

helm uninstall "$RELEASE_NAME" --namespace="${CLUSTER_NAMESPACE}"

remove_dockerhub_secret

if [ -z "$DROP_TAGS" ]
then
remove_tags
fi

remove_iam_resources
