# Deploy Luna to an existing OKE cluster

## Prerequisites

0. [Oracle bash cloud shell cli][0] with the environment variable ENVSUBST pointing to an installation of envsubst (cloud shell does not allow root/sudo package installation).
1. [kubectl][1] with correct context selected: pointing to the cluster you want
   to deploy Luna on.
2. [helm](https://helm.sh/docs/intro/install/): the package manager for
   Kubernetes
3. An existing OKE cluster without autoscaling enabled.

[0]: https://docs.oracle.com/en-us/iaas/Content/API/Concepts/cloudshellintro.htm
[1]: https://kubernetes.io/docs/tasks/tools/#kubectl


## Step 1(optional): Install Nvidia gpu driver for gpu workload

    kubectl apply -f https://raw.githubusercontent.com/NVIDIA/k8s-device-plugin/v0.13.0/nvidia-device-plugin.yml

## Step 2: Deploy Luna

Luna needs cert-manager running in the cluster. Deploy script tries to detect cert-manager in the cluster and installs cert-manager to cert-manager namespace otherwise.

After setting up API keys for oracleidentitycloudservice/<account> and validating that access using ~/.oci/config with key ~/.oci/oci.pem works, deploy using the following:

    ./deploy.sh <oci-cluster-id> <config-file-full-path> <pem-file-full-path> <additional-helm-values(optional)>

Note: This command generates an oci-cluster-id_values.yaml file and (in post 0.5.4 Luna) an oci-cluster-id_values_full.yaml file; please retain these files for use in future upgrades.

## Step 3: Verify Luna

    kubectl get all -n elotl
    
Sample Output
    
```
NAME                                      READY   STATUS    RESTARTS   AGE
pod/elotl-luna-manager-6bd7f4674d-cxwz6   1/1     Running   0          2m39s
pod/elotl-luna-webhook-7fcf5998b6-ltrd6   1/1     Running   0          2m39s
pod/elotl-luna-webhook-7fcf5998b6-svr6b   1/1     Running   0          2m39s

NAME                         TYPE        CLUSTER-IP    EXTERNAL-IP   PORT(S)    AGE
service/elotl-luna-manager   ClusterIP   x.x.x.x       <none>        9090/TCP   2m39s
service/elotl-luna-webhook   ClusterIP   x.x.x.x       <none>        8443/TCP   2m39s

NAME                                 READY   UP-TO-DATE   AVAILABLE   AGE
deployment.apps/elotl-luna-manager   1/1     1            1           2m39s
deployment.apps/elotl-luna-webhook   2/2     2            2           2m39s

NAME                                            DESIRED   CURRENT   READY   AGE
replicaset.apps/elotl-luna-manager-6bd7f4674d   1         1         1       2m39s
replicaset.apps/elotl-luna-webhook-7fcf5998b6   2         2         2       2m39s
```

## Step 4: Run some workloads!

Follow our [tutorial](./POC-TESTING.md) to understand value provided by Luna.

## Step 5: Verify test pod launch and dynamic worker node addition/removal (while testing)

    kubectl get pods --selector=elotl-luna=true -o wide -w
    kubectl get nodes -w

## Upgrade

When running the upgrade command described below, set <retained-values-file> to <retained-path>/<cluster-name>_values_full.yaml, if your installation version was post 0.5.4 Luna, and to <retained-path>/<cluster-name>_values.yaml otherwise.

To upgrade an existing luna deployment, run:

    helm upgrade elotl-luna <chart-path> --wait --namespace=<cluster-namespace> --values=<retained-values-file> <additional-helm-values(optional)>

For example, to upgrade my-cluster from luna-v0.4.6 to luna-v0.5.0 and set an additional helm value binPackingNodeCpu=2, run:

    helm upgrade elotl-luna ./elotl-luna-v0.5.0.tgz --wait --namespace=elotl --values=../../luna-v0.4.6/oke/ocid1.cluster.oc1.iad.aaaaaaaasxamzqh2ch6fmxvk5uierz6sxyicmutae2b2e25tvcybh2azdukq_values.yaml --set binPackingNodeCpu=2

And validate the upgrade as follows:

    helm ls -A
    NAME              NAMESPACE        REVISION        UPDATED                                     STATUS          CHART                    APP VERSION
    elotl-luna        elotl            4               2023-05-19 14:15:30.686251 -0700 PDT        deployed        elotl-luna-v0.5.0        v0.5.0


## Cleanup

    helm uninstall elotl-luna --namespace=elotl
    kubectl delete namespace elotl
