#!/usr/bin/env bash

set -e

OCI_CLUSTER_ID=$1
CONFIG_FIlE_FULL_PATH=$2
PEM_FILE_FULL_PATH=$3
HELM_VALUES="${*:4}"

RELEASE_NAME=${LUNA_RELEASE_NAME:-"elotl-luna"}
CLUSTER_NAMESPACE=${LUNA_CLUSTER_NAMESPACE:-"elotl"}

CHART_PATH=${CHART_PATH:-"./elotl-luna-v*.tgz"}

check_required_args() {
  if test -z "$OCI_CLUSTER_ID" || test -z "$CONFIG_FIlE_FULL_PATH" || test -z "$PEM_FILE_FULL_PATH" ; then
    echo "Usage: $0 <oci-cluster-id> <config-file-full-path> <pem-file-full-path>"
    exit 1
  fi
}

no_helm_chart_installed() {
    if helm -n ${CLUSTER_NAMESPACE} status ${RELEASE_NAME} >/dev/null 2>&1
    then
        cat <<EOF
Upgrading Luna from this script isn’t supported. Please run the following w/<retained-values-file> set to <retained-path>/${CLUSTER_NAME}_values_full.yaml, for post Luna 0.5.4 installation, or <retained-path>/${CLUSTER_NAME}_values.yaml otherwise:

    $ helm upgrade ${RELEASE_NAME} $CHART_PATH --wait --namespace=${CLUSTER_NAMESPACE} --values=<retained-values-file> $HELM_VALUES
EOF
        exit 1
    fi
}

deploy_cert_manager_if_needed() {
  if kubectl wait pods -A -l app.kubernetes.io/instance=cert-manager --for=condition=ready &>/dev/null ; then
    echo "detected cert-manager running"
  else
    echo "no cert-manager deployment found, installing a new one"
    kubectl apply -f https://github.com/cert-manager/cert-manager/releases/download/v1.11.1/cert-manager.yaml &>/dev/null
    if kubectl wait pods -A -l app.kubernetes.io/instance=cert-manager --for=condition=ready --timeout=5m &>/dev/null ; then
      echo "successfully installed cert-manager"
    else
      echo "unable to install cert-manager, aborting"
      exit 1
    fi
  fi
}

deploy() {
    echo "deploying changes to namespace ${CLUSTER_NAMESPACE} in OKE"
    echo "Creating resources..."
    ./create_resources.sh "$OCI_CLUSTER_ID" "$CONFIG_FIlE_FULL_PATH" "$PEM_FILE_FULL_PATH" "$CLUSTER_NAMESPACE"
    echo "deploying luna-manager helm chart in namespace $CLUSTER_NAMESPACE"
    helm install "$RELEASE_NAME" $CHART_PATH \
        --wait \
        --create-namespace \
        --namespace="${CLUSTER_NAMESPACE}" \
        --values="${OCI_CLUSTER_ID}"_values.yaml \
        $HELM_VALUES
    kubectl get cm ${RELEASE_NAME} -n ${CLUSTER_NAMESPACE} -o "jsonpath={.data['config\.yml']}" > "${CLUSTER_NAME}"_values_full.yaml
}

check_required_args
no_helm_chart_installed
deploy_cert_manager_if_needed
deploy
